@@ -6,7 +6,7 @@ use warnings;
 
 our @ISA = qw();
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 
 # Preloaded methods go here.
@@ -17,12 +17,12 @@ __END__
 
 =head1 NAME
 
-CryptoTron::AddrTools - Perl extension for blah blah blah
+CryptoTron::AddrTools - Perl extension for CryptoTron
 
 =head1 SYNOPSIS
 
   use CryptoTron::AddrTools;
-  blah blah blah
+  
 
 =head1 DESCRIPTION
 
@@ -30,7 +30,7 @@ Stub documentation for CryptoTron::AddrTools, created by h2xs. It looks like the
 author of the extension was negligent enough to leave the stub
 unedited.
 
-Blah blah blah.
+Tools for the TRON blockchain. 
 
 
 =head1 SEE ALSO
@@ -46,11 +46,11 @@ If you have a web site set up for your module, mention it here.
 
 =head1 AUTHOR
 
-root, E<lt>root@E<gt>
+Dr. Peter Netz, E<lt>ztenretep@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2022 by root
+Copyright (C) 2022 by Dr. Peter Netz
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.30.0 or,
